#
# spec file for package plplot
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lua_version 5.3

%bcond_with    ocaml_camlidl
%define tk_enabled 1

# SECTION swig is patched on TW to support octave 6, but not on any Leaps
%if 0%{?suse_version} >= 1550
#
# No qhull/octave on arch, ppc
%ifarch %ix86 x86_64
# Octave 8+ unsupported
%define octave_enabled 0
%else
%define octave_enabled 0
%endif
#
%else
%define octave_enabled 0
%endif
# /SECTION

%bcond_without qhull

# FIXME Doesn't build with fPIC (it seems)
%define ada_enabled 0

%define X_display ":98"

%define ada_shlib libplplotada4
%define c_shlib libplplot17
%define cxx_shlib libplplotcxx15
%define csirocsa_shlib libcsirocsa0
%define csironn_shlib libcsironn0
%define fort_shlib libplplotfortran0
%define qsastime_shlib libqsastime0
%define qt_shlib libplplotqt2
%define wx_shlib libplplotwxwidgets1
# DONT SPLIT OUT plplot-tcltk-libs INTO INDIVIDUAL SHARED LIBS AS THEY ARE ALL REQUIRED TOGETHER AND THEIR SO NUMBERING CHANGE IN-STEP WITH EACH OTHER

# Until we have sip for python 3.11
#%%define pythons python310

Name:           plplot
Version:        5.15.0
Release:        bp156.6.8
Summary:        Software package for creating scientific plots
# Main license is LGPL-2.1+, but Octave bindings are licensed as GPL-2.0+
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Scientific/Other
URL:            http://plplot.sourceforge.net/
Source0:        http://download.sf.net/plplot/%{name}-%{version}.tar.gz
Patch0:         plplot-ocaml.patch
# PATCH-FIX-UPSTREAM plplot-5.9.9-ada-pic.patch idoenmez@suse.de -- Compile Ada code with -fPIC
Patch1:         plplot-5.9.9-ada-pic.patch
# PATCH-FIX-UPSTREAM plplot-include-QPainterPath.patch badshah400@gmail.com -- Include QPainterPath header when building Qt modules, needed for Qt >= 5.15.0; patch from upstream
Patch2:         plplot-include-QPainterPath.patch
# PATCH-FIX-UPSTREAM plplot-drop-FindLua-cmake-module.patch badshah400@gmail.com -- Drop in-house FindLua.cmake module, which is severely dated, to use cmake's own module and fix building for lua >= 5.4; patch taken from upstream.
Patch3:         plplot-drop-FindLua-cmake-module.patch
# PATCH-FIX-UPSTREAM https://sourceforge.net/p/plplot/bugs/196/ -- Use reentrant libqhull_r
Patch4:         0001-Use-reentrant-libqhull_r-instead-of-deprecated-libqh.patch
# PATCH-FIX-UPSTREAM support-python3-pythondemos.patch Use print function, so the script works with Python 3
Patch5:         support-python3-pythondemos.patch
# PATCH-FIX-UPSTREAM plplot-libharu-version-check.patch badshah400@gmail.com -- Include correct header for libharu version checks
Patch6:         plplot-libharu-version-check.patch
# List based on build_ada in gcc.spec
ExclusiveArch:  %ix86 x86_64 ppc ppc64 ppc64le s390 s390x ia64 aarch64 riscv64
BuildRequires:  cmake >= 3.13.2
BuildRequires:  fdupes
BuildRequires:  freefont
%if 0%{?ada_enabled}
BuildRequires:  gcc-ada
%endif
BuildRequires:  gcc-fortran >= 6
BuildRequires:  itcl-devel
BuildRequires:  itk
BuildRequires:  java-devel
BuildRequires:  lapack-devel
BuildRequires:  libharu-devel >= 2.3.0
BuildRequires:  libtool
BuildRequires:  ncurses-devel
%if %{with ocaml_camlidl}
BuildRequires:  ocaml
BuildRequires:  ocaml-rpm-macros
BuildRequires:  ocamlfind(camlidl)
BuildRequires:  ocamlfind(findlib)
%endif
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  %{python_module qt5-devel}
BuildRequires:  %{python_module sip4-devel if %python-base < 3.11}
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
%if %{with qhull}
BuildRequires:  qhull_r-devel
%endif
BuildRequires:  swig
BuildRequires:  tcl-devel
BuildRequires:  tk-devel
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(gdlib)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangoft2)
BuildRequires:  pkgconfig(shapelib)
# Required for enabling tk driverand in the %%check section, currently disabled
BuildRequires:  hdf5-devel
%if %{?octave_enabled}
BuildRequires:  octave-devel
%endif
BuildRequires:  wxGTK3-devel >= 3.1
BuildRequires:  xorg-x11-server
BuildRequires:  perl(XML::DOM)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(lasi)
BuildRequires:  pkgconfig(lua)
Requires:       libtool
Requires:       python-numpy
Recommends:     %{name}-doc = %{version}
%define python_subpackage_only 1
%python_subpackages

%description
PLplot is a library of functions that are useful for making scientific
plots.

PLplot can be used from within compiled languages such as C, C++,
FORTRAN and Java, and interactively from interpreted languages such as
Octave, Python, Perl and Tcl.

The PLplot library can be used to create standard x-y plots, semilog
plots, log-log plots, contour plots, 3D surface plots, mesh plots, bar
charts and pie charts. Multiple graphs (of the same or different sizes)
may be placed on a single page with multiple lines in each graph.

A variety of output file devices such as Postscript, png, jpeg, LaTeX
and others, as well as interactive devices such as xwin, tk, xterm and
Tektronics devices are supported. New devices can be easily added by
writing a small number of device dependent routines.

There are almost 2000 characters in the extended character set. This
includes four different fonts, the Greek alphabet and a host of
mathematical, musical, and other symbols. Some devices supports its own
way of dealing with text, such as the Postscript and LaTeX drivers, or
the png and jpeg drivers that uses the Freetype library.

This package provides the shared libraries for PLplot.

%package common
##########################################################################
Summary:        Files for development with PLplot
License:        LGPL-2.1-or-later
Group:          Productivity/Graphics/Visualization/Graph
Provides:       %{name} = %{version}
Obsoletes:      %{name} < 5.12.0

%description common
PLplot is a library of functions that are useful for making scientific
plots.

PLplot can be used from within compiled languages such as C, C++,
FORTRAN and Java, and interactively from interpreted languages such as
Octave, Python, Perl and Tcl.

This package provides some common files shared between the different
PLplot interfaces.

%files common
%dir %{_libdir}/plplot%{version}
%dir %{_libdir}/plplot%{version}/drivers
%dir %{_datadir}/plplot%{version}
%{_libdir}/plplot%{version}/drivers/null.driver_info
%{_libdir}/plplot%{version}/drivers/null.so
%{_libdir}/plplot%{version}/drivers/mem.driver_info
%{_libdir}/plplot%{version}/drivers/mem.so
%{_datadir}/plplot%{version}/*.shp
%{_datadir}/plplot%{version}/*.shx
%{_datadir}/plplot%{version}/ss/
%{_datadir}/plplot%{version}/*.fnt
%{_datadir}/plplot%{version}/*.pal
%dir %{_datadir}/plplot%{version}/examples
%{_datadir}/plplot%{version}/examples/Chloe.pgm
%{_datadir}/plplot%{version}/examples/README.Chloe
##########################################################################

%package devel
##########################################################################
Summary:        Files for development with PLplot
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       %{c_shlib} = %{version}
Requires:       %{csirocsa_shlib} = %{version}
%if %{with qhull}
Requires:       %{csironn_shlib} = %{version}
%endif
Requires:       %{qsastime_shlib} = %{version}
Requires:       gcc-c++
Requires:       pkgconfig
Requires:       plplot-common = %{version}
Requires:       pkgconfig(freetype2)
Provides:       %{name} = %{version}
Obsoletes:      %{name} < 5.12.0

%description devel
PLplot is a library of functions that are useful for making scientific
plots.

PLplot can be used from within compiled languages such as C, C++,
FORTRAN and Java, and interactively from interpreted languages such as
Octave, Python, Perl and Tcl.

This package provides the files necessary for development with PLplot
in C.

%post devel
/sbin/install-info %{_infodir}/plplotdoc.info %{_infodir}/dir

%preun devel
/sbin/install-info --delete %{_infodir}/plplotdoc.info %{_infodir}/dir

%files devel -f %{_builddir}/%{name}.filelist.ocaml
%license COPYING.LIB Copyright
%doc AUTHORS FAQ README README.release
%{_bindir}/pltek
%{_infodir}/plplotdoc.info*
%{_mandir}/man1/pltek.1.gz
%{_includedir}/plplot/
%exclude %{_includedir}/plplot/plstream.h
%{_libdir}/libcsirocsa.so
%{_libdir}/libplplot.so
%{_libdir}/libqsastime.so
%{_libdir}/pkgconfig/plplot.pc
%dir %{_libdir}/cmake/plplot
%{_libdir}/cmake/plplot/export_csirocsa.cmake
%{_libdir}/cmake/plplot/export_csirocsa-*.cmake
%if %{with qhull}
%{_libdir}/libcsironn.so
%{_libdir}/cmake/plplot/export_csironn.cmake
%{_libdir}/cmake/plplot/export_csironn-*.cmake
%endif
%{_libdir}/cmake/plplot/export_mem.cmake
%{_libdir}/cmake/plplot/export_mem-*.cmake
%{_libdir}/cmake/plplot/export_null.cmake
%{_libdir}/cmake/plplot/export_null-*.cmake
%{_libdir}/cmake/plplot/export_plplot.cmake
%{_libdir}/cmake/plplot/export_plplot-*.cmake
%{_libdir}/cmake/plplot/export_plplotc.cmake
%{_libdir}/cmake/plplot/export_plplotc-*.cmake
%{_libdir}/cmake/plplot/export_plserver.cmake
%{_libdir}/cmake/plplot/export_plserver-*.cmake
%{_libdir}/cmake/plplot/export_pltek.cmake
%{_libdir}/cmake/plplot/export_pltek-*.cmake
%{_libdir}/cmake/plplot/export_qsastime.cmake
%{_libdir}/cmake/plplot/export_qsastime-*.cmake
%{_libdir}/cmake/plplot/plplotConfig.cmake
%{_libdir}/cmake/plplot/plplot_exports.cmake
%{_mandir}/man3/pl*.3*
# PLMETA DRIVER DISABLED
#%%{_bindir}/plm2gif
#%%{_bindir}/plpr
#%%{_bindir}/plrender
#%%{_mandir}/man1/plm2gif.1.gz
#%%{_mandir}/man1/plpr.1.gz
#%%{_mandir}/man1/plrender.1.gz
#%%{_datadir}/plplot%%{version}/examples/test_plrender.sh
#%%{_libdir}/plplot%%{version}/drivers/plmeta.driver_info
#%%{_libdir}/plplot%%{version}/drivers/plmeta.so
%dir %{_datadir}/plplot%{version}/examples
%dir %{_datadir}/plplot%{version}/examples/plplot_test
%{_datadir}/plplot%{version}/examples/CTestConfig.cmake
%{_datadir}/plplot%{version}/examples/CTestCustom.cmake.in
%{_datadir}/plplot%{version}/examples/plplot-test.sh
%{_datadir}/plplot%{version}/examples/plplot-test-interactive.sh
%{_datadir}/plplot%{version}/examples/c/
%{_datadir}/plplot%{version}/examples/c++/
%{_datadir}/plplot%{version}/examples/Makefile
%{_datadir}/plplot%{version}/examples/plplot_test/CMakeLists.txt
%{_datadir}/plplot%{version}/examples/test_c.sh
%{_datadir}/plplot%{version}/examples/test_c_interactive.sh
%{_datadir}/plplot%{version}/examples/test_cxx.sh
%{_datadir}/plplot%{version}/examples/test_diff.sh
%if %{with ocaml_camlidl}
%{_libdir}/pkgconfig/plplot-ocaml.pc
%{_datadir}/plplot%{version}/examples/ocaml
%{_datadir}/plplot%{version}/examples/test_ocaml.sh
%endif

##########################################################################

%package doc
##########################################################################
Summary:        Documentation for PLplot and its bindings
License:        LGPL-2.1-or-later
Group:          Documentation/Other
BuildArch:      noarch

%description doc
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the documentation for PLplot and its associated
modules.

%files doc
%dir %{_docdir}/%{name}-doc
%{_docdir}/%{name}-doc/*
##########################################################################

%if 0%{?ada_enabled}
%package -n %{ada_shlib}
##########################################################################
Summary:        Shared libraries for PLplot's Ada bindings
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n %{ada_shlib}
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the shared libraries necessary for using PLplot
with Ada.

%post -n %{ada_shlib} -p /sbin/ldconfig

%postun -n %{ada_shlib} -p /sbin/ldconfig

%files -n %{ada_shlib}
%{_libdir}/libplplotada.so.*
##########################################################################

%package -n %{name}ada-devel
##########################################################################
Summary:        Ada bindings for development with PLplot
License:        LGPL-2.1-or-later
Group:          Development/Languages/Other
Requires:       %{ada_shlib} = %{version}
Requires:       %{name}-common = %{version}
Requires:       gcc-ada
Requires:       pkgconfig
Provides:       %{name}-ada-devel = %{version}
Obsoletes:      %{name}-ada-devel < 5.12.0

%description -n %{name}ada-devel
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the files necessary for using PLplot in Ada.

%files -n %{name}ada-devel
%dir %{_libdir}/ada
%dir %{_libdir}/ada/adalib
%dir %{_datadir}/ada
%dir %{_datadir}/ada/adainclude
%{_libdir}/libplplotada.so
%{_libdir}/ada/adalib/plplotada/
%{_libdir}/pkgconfig/plplot-ada.pc
%{_libdir}/cmake/plplot/export_plplotada.cmake
%{_libdir}/cmake/plplot/export_plplotada-*.cmake
%{_datadir}/ada/adainclude/plplotada/
%{_datadir}/plplot%{version}/examples/ada/
%{_datadir}/plplot%{version}/examples/test_ada.sh
##########################################################################
%endif

%package -n %{fort_shlib}
##########################################################################
Summary:        Shared libraries for PLplot's Fortran bindings
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n %{fort_shlib}
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the shared libraries necessary for using PLplot
with Fortran.

%post -n %{fort_shlib} -p /sbin/ldconfig

%postun -n %{fort_shlib} -p /sbin/ldconfig

%files -n %{fort_shlib}
%{_libdir}/libplplotfortran.so.*
##########################################################################

%package -n %{name}fortran-devel
##########################################################################
Summary:        Fortran bindings for development with PLplot
License:        LGPL-2.1-or-later
Group:          Development/Languages/Fortran
Requires:       %{fort_shlib} = %{version}
Requires:       %{name}-common = %{version}
Requires:       gcc-fortran
Requires:       pkgconfig
Obsoletes:      %{name}f95-devel < 5.13.0
Provides:       %{name}f95-devel = %{version}
Obsoletes:      %{name}-fortran-devel < 5.12.0
Provides:       %{name}-fortran-devel = %{version}

%description -n %{name}fortran-devel
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the files necessary for using PLplot in Fortran.

%files -n %{name}fortran-devel
%dir %{_libdir}/fortran
%dir %{_libdir}/fortran/modules
%{_libdir}/fortran/modules/plplot/
%{_libdir}/libplplotfortran.so
%{_libdir}/pkgconfig/plplot-fortran.pc
%{_libdir}/cmake/plplot/export_plfortrandemolib.cmake
%{_libdir}/cmake/plplot/export_plfortrandemolib-*.cmake
%{_libdir}/cmake/plplot/export_plplotfortran.cmake
%{_libdir}/cmake/plplot/export_plplotfortran-*.cmake
%{_datadir}/plplot%{version}/examples/fortran/
%{_datadir}/plplot%{version}/examples/test_fortran.sh
##########################################################################

%package java
##########################################################################
Summary:        PLplot functions for scientific plotting with Java
License:        LGPL-2.1-or-later
Group:          Productivity/Scientific/Other
Requires:       %{name}-common = %{version}
Requires:       java

%description java
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the PLplot functions required for scientific
plotting with Java.

%files java
%{_libdir}/plplot%{version}/libplplotjavac_wrap.so
%{_libdir}/cmake/plplot/export_plplotjavac_wrap.cmake
%{_libdir}/cmake/plplot/export_plplotjavac_wrap-*.cmake
%{_datadir}/java/plplot.jar
%{_datadir}/plplot%{version}/examples/java/
%{_datadir}/plplot%{version}/examples/test_java.sh
##########################################################################

%package lua
##########################################################################
Summary:        PLplot functions for scientific plotting with Lua
License:        LGPL-2.1-or-later
Group:          Development/Libraries/Other
Requires:       %{name}-common = %{version}
Requires:       lua

%description lua
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the PLplot functions required for scientific
plotting with Lua.

%files lua
%{_libdir}/lua/plplot/
%{_libdir}/cmake/plplot/export_plplotluac.cmake
%{_libdir}/cmake/plplot/export_plplotluac-*.cmake
%{_datadir}/plplot%{version}/examples/lua/
%{_datadir}/plplot%{version}/examples/test_lua.sh
##########################################################################

%package octave
##########################################################################
Summary:        PLplot functions for scientific plotting with Octave
License:        GPL-2.0-or-later
Group:          Development/Libraries/Other
Requires:       %{name}-common = %{version}
Requires:       octave

%description octave
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the PLplot functions required for scientific
plotting with Octave.

%if 0%{?octave_enabled}
%files octave
%{_datadir}/%{name}_octave/
%{_datadir}/octave/site/m/PLplot/
%{_libdir}/octave/site/oct/*/plplot_octave.oct
%{_libdir}/cmake/plplot/export_plplot_octave-*.cmake
%{_libdir}/cmake/plplot/export_plplot_octave.cmake
%{_datadir}/plplot%{version}/examples/octave/
%{_datadir}/plplot%{version}/examples/test_octave.sh
%endif
##########################################################################

%if "%{python_flavor}" != "python311"
%package -n python-plplot-pyqt5
##########################################################################
Summary:        PLplot functions for scientific plotting with python-qt5
License:        LGPL-2.1-or-later
Group:          Development/Libraries/Python
Requires:       %{name}-common = %{version}
Requires:       python-qt5
# Python 3.10 is the last version of Python with sip4 support
%if "%{python_flavor}" == "python3" || "%{python_flavor}" == "python310"
Obsoletes:      plplot-python3-qt < %{version}-%{release}
Provides:       plplot-python3-qt = %{version}-%{release}
Recommends:     plplot-pyqt5-cmake
%endif

%description -n python-plplot-pyqt5
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the PLplot functions required for scientific
plotting with python-qt.

%files %{python_files plplot-pyqt5}
%{python_sitearch}/plplot_pyqt5.so
%endif
##########################################################################

%package -n plplot-pyqt5-cmake
##########################################################################
Summary:        PLplot functions for scientific plotting with python-qt5
License:        LGPL-2.1-or-later
Group:          Development/Libraries/Python
Requires:       python3-plplot-pyqt5

%description -n plplot-pyqt5-cmake
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the cmake files optionally required for building
cmake based projects with plplot-pyqt5.

%if ("%{python_flavor}" == "python3" || "%{python_provides}" == "python3") && "%{python_flavor}" != "python311"
%files -n plplot-pyqt5-cmake
%{_libdir}/cmake/plplot/export_plplot_pyqt5.cmake
%{_libdir}/cmake/plplot/export_plplot_pyqt5-*.cmake
%endif
##########################################################################

%package -n %{qt_shlib}
##########################################################################
Summary:        PLplot functions for scientific plotting with Qt
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n %{qt_shlib}
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the PLplot functions required for scientific
plotting with Qt.

%post -n %{qt_shlib} -p /sbin/ldconfig

%postun -n %{qt_shlib} -p /sbin/ldconfig

%files -n %{qt_shlib}
%{_libdir}/libplplotqt.so.*
##########################################################################

%package -n %{name}qt-devel
##########################################################################
Summary:        PLplot functions for scientific plotting with qt
License:        LGPL-2.1-or-later
Group:          Development/Libraries/Other
Requires:       %{qt_shlib} = %{version}
Requires:       pkgconfig
Requires:       pkgconfig(Qt5Core)
Requires:       pkgconfig(Qt5Gui)
Requires:       pkgconfig(Qt5PrintSupport)
Requires:       pkgconfig(Qt5Svg)
Requires:       pkgconfig(Qt5Widgets)
Provides:       %{name}-qt-devel = %{version}
Obsoletes:      %{name}-qt-devel < 5.12.0
Requires:       %{name}-common = %{version}

%description -n %{name}qt-devel
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the development files for using PLplot
with Qt.

%files -n %{name}qt-devel
%{_libdir}/libplplotqt.so
%{_libdir}/pkgconfig/plplot-qt.pc
%{_libdir}/plplot%{version}/drivers/qt.driver_info
%{_libdir}/plplot%{version}/drivers/qt.so
%{_libdir}/cmake/plplot/export_plplotqt.cmake
%{_libdir}/cmake/plplot/export_plplotqt-*.cmake
%{_libdir}/cmake/plplot/export_qt.cmake
%{_libdir}/cmake/plplot/export_qt-*.cmake
##########################################################################

%package tcltk-libs
##########################################################################
Summary:        PLplot functions for scientific plotting with Tcl/Tk
License:        LGPL-2.1-or-later
Group:          System/Libraries
Provides:       %{name}-tcltk = %{version}
Obsoletes:      %{name}-tcltk < 5.12.0

%description tcltk-libs
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the PLplot functions required for scientific
plotting with Tcl/Tk.

%post tcltk-libs -p /sbin/ldconfig

%postun tcltk-libs -p /sbin/ldconfig

%files tcltk-libs
%{_libdir}/libplplottcltk*.so.*
%{_libdir}/libtclmatrix.so.*
##########################################################################

%package tcltk-devel
##########################################################################
Summary:        PLplot functions for scientific plotting with Tcl/Tk
License:        LGPL-2.1-or-later
Group:          Development/Libraries/Other
Requires:       %{name}-common = %{version}
Requires:       %{name}-tcltk-libs = %{version}
Requires:       itcl-devel
Requires:       itk
Requires:       pkgconfig
Requires:       tcl-devel
Requires:       tk-devel

%description tcltk-devel
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the development files for using PLplot with Tcl/Tk.

%files tcltk-devel
%{_bindir}/pltcl
%{_libdir}/libplplottcltk*.so
%{_libdir}/libtclmatrix.so
%{_libdir}/cmake/plplot/export_pltcl.cmake
%{_libdir}/cmake/plplot/export_pltcl-*.cmake
%{_libdir}/pkgconfig/plplot-tcl*.pc
%{_libdir}/cmake/plplot/export_tclmatrix.cmake
%{_libdir}/cmake/plplot/export_tclmatrix-*.cmake
%{_datadir}/plplot%{version}/examples/test_tcl.sh
%{_datadir}/plplot%{version}/examples/tcl/
%{_datadir}/plplot%{version}/pkgIndex.tcl
%{_datadir}/plplot%{version}/tcl/
%{_mandir}/man1/plserver.1.gz
%{_mandir}/man1/pltcl.1.gz

%if %{tk_enabled}
%{_bindir}/plserver
%{_datadir}/plplot%{version}/examples/tk/
%{_libdir}/plplot%{version}/drivers/tk.driver_info
%{_libdir}/plplot%{version}/drivers/tk.so
%{_libdir}/plplot%{version}/drivers/tkwin.driver_info
%{_libdir}/plplot%{version}/drivers/tkwin.so
%{_libdir}/cmake/plplot/export_tk.cmake
%{_libdir}/cmake/plplot/export_tk-*.cmake
%{_libdir}/cmake/plplot/export_tkwin.cmake
%{_libdir}/cmake/plplot/export_tkwin-*.cmake
%{_libdir}/cmake/plplot/export_plplottcltk.cmake
%{_libdir}/cmake/plplot/export_plplottcltk_Main.cmake
%{_libdir}/cmake/plplot/export_plplottcltk_Main-*.cmake
%{_libdir}/cmake/plplot/export_plplottcltk-*.cmake
%{_libdir}/cmake/plplot/export_Pltk_init.cmake
%{_libdir}/cmake/plplot/export_Pltk_init-*.cmake
%{python_sitearch}/Plframe.py*
%{python_sitearch}/TclSup.py*
%{python_sitearch}/*Pltk_init.*
%endif

##########################################################################

%package -n %{wx_shlib}
##########################################################################
Summary:        PLplot functions for scientific plotting with wxWidgets
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n %{wx_shlib}
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the PLplot functions required for scientific
plotting with wxWidgets.

%post -n %{wx_shlib} -p /sbin/ldconfig

%postun -n %{wx_shlib} -p /sbin/ldconfig

%files -n %{wx_shlib}
%{_libdir}/libplplotwxwidgets.so.*
##########################################################################

%package wxwidgets
##########################################################################
Summary:        PLplot plot viewer built on wxWidgets
License:        LGPL-2.1-or-later
Group:          Productivity/Graphics/Visualization/Graph
Requires:       %{name}-common = %{version}
Requires:       %{wx_shlib} = %{version}

%description wxwidgets
PLplot is a library of functions that are useful for making scientific
plots.

This package provides a PLplot viewer built using the wxWidgets GUI API.

%files wxwidgets
%{_bindir}/wxPLViewer
%{_libdir}/cmake/plplot/export_wxPLViewer.cmake
%{_libdir}/cmake/plplot/export_wxPLViewer-*.cmake
##########################################################################

%package -n %{name}wxwidgets-devel
##########################################################################
Summary:        PLplot bindings for development with wxWidgets
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}
Requires:       %{wx_shlib} = %{version}
Requires:       pkgconfig
Requires:       wxWidgets-devel
Provides:       %{name}-wxwidgets-devel = %{version}
Obsoletes:      %{name}-wxwidgets-devel < 5.12.0
Requires:       %{name}-common = %{version}

%description -n %{name}wxwidgets-devel
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the PLplot functions required for scientific
plotting with wxWidgets.

%files -n %{name}wxwidgets-devel
%{_libdir}/libplplotwxwidgets.so
%{_libdir}/pkgconfig/plplot-wxwidgets.pc
%{_libdir}/plplot%{version}/drivers/wxwidgets.driver_info
%{_libdir}/plplot%{version}/drivers/wxwidgets.so
%{_libdir}/cmake/plplot/export_plplotwxwidgets.cmake
%{_libdir}/cmake/plplot/export_plplotwxwidgets-*.cmake
%{_libdir}/cmake/plplot/export_wxwidgets.cmake
%{_libdir}/cmake/plplot/export_wxwidgets-*.cmake
##########################################################################

%package -n %{c_shlib}
##########################################################################
Summary:        PLplot functions for scientific plotting with C
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n %{c_shlib}
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the shared lib for PLplot's C binding.

%post -n %{c_shlib} -p /sbin/ldconfig

%postun -n %{c_shlib} -p /sbin/ldconfig

%files -n %{c_shlib}
%{_libdir}/libplplot.so.*
##########################################################################

%package -n %{cxx_shlib}
##########################################################################
Summary:        PLplot functions for scientific plotting with C++
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n %{cxx_shlib}
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the shared lib for PLplot's C++ binding.

%post -n %{cxx_shlib} -p /sbin/ldconfig

%postun -n %{cxx_shlib} -p /sbin/ldconfig

%files -n %{cxx_shlib}
%{_libdir}/libplplotcxx.so.*
##########################################################################

%package -n plplotcxx-devel
##########################################################################
Summary:        PLplot functions for scientific plotting with C++
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       %{cxx_shlib} = %{version}
Requires:       %{name}-common = %{version}

%description -n plplotcxx-devel
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the shared lib for PLplot's C++ binding.

%files -n plplotcxx-devel
%{_libdir}/libplplotcxx.so
%{_libdir}/pkgconfig/plplot-c++.pc
%{_libdir}/cmake/plplot/export_plplotcxx.cmake
%{_libdir}/cmake/plplot/export_plplotcxx-*.cmake
%{_includedir}/plplot/plstream.h
##########################################################################

%package -n %{csirocsa_shlib}
##########################################################################
Summary:        PLplot csirocsa component
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n %{csirocsa_shlib}
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the shared lib for PLplot's csirocsa.

%post -n %{csirocsa_shlib} -p /sbin/ldconfig

%postun -n %{csirocsa_shlib} -p /sbin/ldconfig

%files -n %{csirocsa_shlib}
%{_libdir}/libcsirocsa.so.*
##########################################################################

%if %{with qhull}
%package -n %{csironn_shlib}
##########################################################################
Summary:        PLplot csironn component
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n %{csironn_shlib}
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the shared lib for PLplot's csironn.

%post -n %{csironn_shlib} -p /sbin/ldconfig

%postun -n %{csironn_shlib} -p /sbin/ldconfig

%files -n %{csironn_shlib}
%{_libdir}/libcsironn.so.*
%endif
##########################################################################

%package -n %{qsastime_shlib}
##########################################################################
Summary:        PLplot qsatime component
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n %{qsastime_shlib}
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the shared lib for PLplot's qsatime.

%post -n %{qsastime_shlib} -p /sbin/ldconfig

%postun -n %{qsastime_shlib} -p /sbin/ldconfig

%files -n %{qsastime_shlib}
%{_libdir}/libqsastime.so.*
##########################################################################

%package -n python-%{name}
##########################################################################
Summary:        PLplot functions for scientific plotting with Python
License:        LGPL-2.1-or-later
Group:          System/Libraries
Requires:       %{name}-common = %{version}
Requires:       python-base
Requires:       python-numpy
# For update from the last python3-plplot package built against python3.10
%if "%{python_flavor}" == "python310"
Conflicts:      python3-%{name} < %{version}-%{release}
%endif
%if "%{python_flavor}" == "python3" || "%{python_provides}" == "python3"
Obsoletes:      python3-%{name} < %{version}-%{release}
Provides:       python3-%{name} = %{version}-%{release}
%endif

%description -n python-%{name}
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the PLplot's Python binding.

%files %{python_files %{name}}
%{python_sitearch}/_plplotc.so
%{python_sitearch}/plplot.py
%{python_sitearch}/plplotc.py
%{_datadir}/plplot%{version}/examples/python%{python_version}/
%{_datadir}/plplot%{version}/examples/test_python%{python_version}.sh
##########################################################################

%package driver-cairo
##########################################################################
Summary:        PLplot driver using the cairo backend
License:        LGPL-2.1-or-later
Group:          System/Libraries
Requires:       plplot-common = %{version}

%description driver-cairo
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the cairo driver for plotting using PLplot.

%files driver-cairo
%{_libdir}/plplot%{version}/drivers/cairo.driver_info
%{_libdir}/plplot%{version}/drivers/cairo.so
%{_libdir}/cmake/plplot/export_cairo.cmake
%{_libdir}/cmake/plplot/export_cairo-*.cmake
##########################################################################

%package driver-ntk
##########################################################################
Summary:        PLplot driver using the ntk backend
License:        LGPL-2.1-or-later
Group:          System/Libraries
Requires:       plplot-common = %{version}

%description driver-ntk
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the ntk driver for plotting using PLplot.

%files driver-ntk
%{_libdir}/plplot%{version}/drivers/ntk.driver_info
%{_libdir}/plplot%{version}/drivers/ntk.so
%{_libdir}/cmake/plplot/export_ntk.cmake
%{_libdir}/cmake/plplot/export_ntk-*.cmake
##########################################################################

%package driver-pdf
##########################################################################
Summary:        PLplot driver using the pdf backend
License:        LGPL-2.1-or-later
Group:          System/Libraries
Requires:       plplot-common = %{version}

%description driver-pdf
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the pdf driver for plotting using PLplot.

%files driver-pdf
%{_libdir}/plplot%{version}/drivers/pdf.driver_info
%{_libdir}/plplot%{version}/drivers/pdf.so
%{_libdir}/cmake/plplot/export_pdf.cmake
%{_libdir}/cmake/plplot/export_pdf-*.cmake
##########################################################################

%package driver-ps
##########################################################################
Summary:        PLplot driver using the ps backend
License:        LGPL-2.1-or-later
Group:          System/Libraries
Requires:       plplot-common = %{version}

%description driver-ps
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the ps driver for plotting using PLplot.

%files driver-ps
%{_libdir}/plplot%{version}/drivers/ps.driver_info
%{_libdir}/plplot%{version}/drivers/ps.so
%{_libdir}/cmake/plplot/export_ps.cmake
%{_libdir}/cmake/plplot/export_ps-*.cmake
##########################################################################

%package driver-psttf
##########################################################################
Summary:        PLplot driver using the psttf backend
License:        LGPL-2.1-or-later
Group:          System/Libraries
Requires:       plplot-common = %{version}

%description driver-psttf
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the psttf driver for plotting using PLplot.

%files driver-psttf
%{_libdir}/plplot%{version}/drivers/psttf.driver_info
%{_libdir}/plplot%{version}/drivers/psttf.so
%{_libdir}/cmake/plplot/export_psttf.cmake
%{_libdir}/cmake/plplot/export_psttf-*.cmake
##########################################################################

%package driver-svg
##########################################################################
Summary:        PLplot driver using the SVG backend
License:        LGPL-2.1-or-later
Group:          System/Libraries
Requires:       plplot-common = %{version}

%description driver-svg
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the SVG driver for plotting using PLplot.

%files driver-svg
%{_libdir}/plplot%{version}/drivers/svg.driver_info
%{_libdir}/plplot%{version}/drivers/svg.so
%{_libdir}/cmake/plplot/export_svg.cmake
%{_libdir}/cmake/plplot/export_svg-*.cmake
##########################################################################

%package driver-xfig
##########################################################################
Summary:        PLplot driver using the xfig backend
License:        LGPL-2.1-or-later
Group:          System/Libraries
Requires:       plplot-common = %{version}

%description driver-xfig
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the xfig driver for plotting using PLplot.

%files driver-xfig
%{_libdir}/plplot%{version}/drivers/xfig.driver_info
%{_libdir}/plplot%{version}/drivers/xfig.so
%{_libdir}/cmake/plplot/export_xfig.cmake
%{_libdir}/cmake/plplot/export_xfig-*.cmake
##########################################################################

%package driver-xwin
##########################################################################
Summary:        PLplot driver using the xwin backend
License:        LGPL-2.1-or-later
Group:          System/Libraries
Requires:       plplot-common = %{version}

%description driver-xwin
PLplot is a library of functions that are useful for making scientific
plots.

This package provides the xwin driver for plotting using PLplot.

%files driver-xwin
%{_libdir}/plplot%{version}/drivers/xwin.driver_info
%{_libdir}/plplot%{version}/drivers/xwin.so
%{_libdir}/cmake/plplot/export_xwin.cmake
%{_libdir}/cmake/plplot/export_xwin-*.cmake
##########################################################################

%prep
%autosetup -p1

%build
for file in NEWS README.release
do
  iconv -f ISO-8859-1 -t UTF-8 $file > ${file}.tmp
  touch -r $file ${file}.tmp
  mv ${file}.tmp $file
done

export CFLAGS="%{optflags} -DUSE_INTERP_RESULT -fno-strict-aliasing"
# c++14 needs to use explicitly to avoid issues with GCC 11
export CXXFLAGS="%{optflags} -std=c++14 -fno-strict-aliasing"
export FFLAGS="%{optflags}"
export LDFLAGS="-fPIC"

# X-server and $DISPLAY required to enable tk bindings
export DISPLAY=%{X_display}
Xvfb -noreset %{X_display} >& Xvfb.log &
trap "kill $! || true" EXIT
sleep 5
%{python_expand #Set the $python var
# Define cmake common opts
export CMAKE_COMMON_OPTS="-DCMAKE_INSTALL_LIBDIR:PATH=%{_libdir} \
-DENABLE_compiler_diagnostics=ON \
-DPL_FREETYPE_FONT_PATH:PATH=\"%{_datadir}/fonts/truetype\" \
-DUSE_RPATH:BOOL=OFF \
-DCMAKE_SKIP_RPATH:BOOL=OFF \
-DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON \
-DBUILD_DOC:BOOL=OFF \
-DBUILD_TEST:BOOL=ON  \
-DENABLE_python:BOOL=ON \
-DENABLE_qt:BOOL=ON \
-DPLPLOT_PYTHON_EXACT_VERSION=%{$python_version} \
-DPLPLOT_USE_QT5:BOOL=ON \
-DPLD_pdfcairo:BOOL=ON \
-DPLD_pngcairo:BOOL=ON \
-DPLD_pscairo:BOOL=ON \
-DPLD_epscairo:BOOL=ON \
-DPLD_svgcairo:BOOL=ON \
-DPLD_epsqt:BOOL=OFF \
-DPLD_pdfqt:BOOL=ON \
-DPLD_bmpqt:BOOL=ON \
-DPLD_jpgqt:BOOL=ON \
-DPLD_pngqt:BOOL=ON \
-DPLD_ppmqt:BOOL=ON \
-DPLD_tiffqt:BOOL=ON \
-DPLD_svgqt:BOOL=ON \
-DPLD_pdf:BOOL=ON \
-DPLD_ps:BOOL=ON \
-DPLD_psc:BOOL=ON \
-DPLD_psttf:BOOL=ON \
-DPLD_psttfc:BOOL=ON \
-DPLD_qtwidget:BOOL=ON \
-DPLD_svg:BOOL=ON \
-DPLD_xfig:BOOL=ON \
-DPLD_xcairo:BOOL=ON \
-DPLD_extcairo:BOOL=ON \
-DPLD_extqt:BOOL=ON \
-DPLD_wxpng:BOOL=OFF \
-DPLD_wxwidgets:BOOL=ON
"

mkdir ../$python
cp -pr ./* ../$python
pushd ../$python
if [ ${python_flavor} = python311 ]; then
  export CMAKE_COMMON_OPTS="${CMAKE_COMMON_OPTS} -DENABLE_pyqt5:BOOL=OFF"
else
  export CMAKE_COMMON_OPTS="${CMAKE_COMMON_OPTS} -DENABLE_pyqt5:BOOL=ON"
fi
%cmake ${CMAKE_COMMON_OPTS} \
%if "$python_" == "python3_" || "%{$python_provides}" == "python3"
        -DENABLE_ada:BOOL=%{?ada_enabled:ON}%{!?ada_enabled:OFF} \
        -DENABLE_cxx:BOOL=ON \
        -DENABLE_d:BOOL=OFF \
        -DENABLE_fortran:BOOL=ON \
        -DENABLE_itcl:BOOL=ON \
        -DENABLE_itk:BOOL=%{?tk_enabled:ON}%{!?tk_enabled:OFF} \
        -DENABLE_java:BOOL=ON \
        -DENABLE_lua:BOOL=ON \
        -DENABLE_ocaml:BOOL=%{?with_ocaml_camlidl:ON}%{!?with_ocaml_camlidl:OFF} \
        -DENABLE_octave:BOOL=%{?octave_enabled:ON}%{!?octave_enabled:OFF} \
        -DENABLE_tcl:BOOL=ON \
        -DENABLE_tk:BOOL=%{?tk_enabled:ON}%{!?tk_enabled:OFF} \
        -DENABLE_wxwidgets:BOOL=ON \
        -DPREBUILT_DOC:BOOL=ON \
				-DJAVAWRAPPER_DIR:PATH="%{_libdir}/plplot%{version}" \
        -DTRY_OCTAVE4=ON
%else
        -DDEFAULT_NO_BINDINGS:BOOL=ON \
        -DPREBUILT_DOC:BOOL=OFF
%endif

%cmake_build
popd
}

%install
%{python_expand pushd ../$python
%cmake_install
> %{_builddir}/%{name}.filelist.ocaml
%if %{with ocaml_camlidl}
: creating '%{name}.files' and '%{name}.files.devel'
%ocaml_create_file_list
mv %{name}.files.devel %{_builddir}/%{name}.filelist.ocaml
%endif

%if "$python_" == "python3_" || "%{$python_provides}" == "python3"
# Fix up tclIndex files so they are the same on all builds
for file in %{buildroot}%{_datadir}/plplot%{version}/examples/*/tclIndex
do
   grep '^[# ]' ${file} > tclIndex.hd
   grep -v '^[# ]' ${file} | sort > tclIndex
   cat tclIndex.hd tclIndex > ${file}
done
rm -rf %{buildroot}%{_datadir}/plplot%{version}/examples/cmake/modules/Platform

#Remove unnecessary examples that trigger build errors or warnings
rm -f %{buildroot}%{_datadir}/%{name}%{version}/examples/cmake/modules/export_plplot-*.cmake
rm -f %{buildroot}%{_datadir}/%{name}%{version}/examples/test_octave_interactive.sh
rm -f %{buildroot}%{_datadir}/%{name}%{version}/examples/tk/*.in
rm -f %{buildroot}%{_datadir}/%{name}%{version}/examples/tcl/*.in
rm -f %{buildroot}%{_datadir}/%{name}%{version}/examples/tk/tk01

#Remove cmake files for the examples since they don't work anyway due to presence of rpath
rm -f %{buildroot}%{_datadir}/plplot%{version}/examples/CMakeLists.txt
rm -fr %{buildroot}%{_datadir}/plplot%{version}/examples/cmake

#Move doc files to appropriate location
mkdir -p %{buildroot}%{_docdir}
mv %{buildroot}%{_datadir}/doc/%{name} %{buildroot}%{_docdir}/%{name}-doc

%if %{tk_enabled}
#Grant executable permissions to example tk binaries with valid shebang
chmod +x %{buildroot}%{_datadir}/%{name}%{version}/examples/tk/tk03
%endif

#Remove a fortran static library
rm %{buildroot}%{_libdir}/libplfortrandemolib*.a

sed -i "1{s@/usr/bin/env python@%{_bindir}/python%{$python_bin_suffix}@;}" %{buildroot}%{_datadir}/%{name}%{version}/examples/python/pytkdemo
%endif

#Fix python hashbangs for examples (/usr/bin/env python -> /usr/bin/pythonX.Y)
sed -i "1{s@/usr/bin/env python@%{_bindir}/python%{$python_bin_suffix}@;}" %{buildroot}%{_datadir}/%{name}%{version}/examples/python/x*
sed -i "1{s@/usr/bin/env python@%{_bindir}/python%{$python_bin_suffix}@;}" %{buildroot}%{_datadir}/%{name}%{version}/examples/python/*.py

# Move examples to versioned python dirs
mv %{buildroot}%{_datadir}/plplot%{version}/examples/python \
   %{buildroot}%{_datadir}/plplot%{version}/examples/python%{$python_version}
mv %{buildroot}%{_datadir}/plplot%{version}/examples/test_python.sh \
   %{buildroot}%{_datadir}/plplot%{version}/examples/test_python%{$python_version}.sh

# Only keep for primary flavour
if [ "${python_flavor}" != "python3" ] && [ "%{$python_provides}" != "python3" ]
then
  rm %{buildroot}%{_libdir}/cmake/plplot/export_plplot_pyqt5*.cmake
fi

%fdupes %{buildroot}%{_datadir}/
popd
}

%check
export DISPLAY=%{X_display}
Xvfb %{X_display} >& Xvfb.log &
trap "kill $! || true" EXIT
sleep 5
%{python_expand pushd ../$python
cd %__builddir
# Octave tests fail, known issue with tests
# Qt tests fail on Xvfb
# Avoid fontconfig warnings about un-writable cache dirs by setting HOME to pwd
export HOME=.
ctest -V -E "octave|qt" %{?_smp_mflags}
popd
}

%changelog
* Sun Jun 25 2023 Atri Bhattacharya <badshah400@gmail.com>
- Adapt specfile to build plplot against multiple python flavours.
- Set $HOME to current dir during %%check to ensure fontconfig does
  not complain about un-writable cache dirs.
- Add plplot-libharu-version-check.patch: Fix check for libharu
  version when configuring build with cmake.
- New subpackages:
  * plplot-driver-pdf: PDf driver based on libharu; new
    BuildRequires: libharu-devel.
  * plplot-pyqt5-cmake: CMake files for building cmake based
    projects using python3-plplot-pyqt5. CMake files are not
    versioned according to python3 versioning, and so can only
    help when using the pyqt5 bindings with the primary python3
    version. NOTE: Currently pkg is noop as pyqt5 bindings do not
    build for python 3.11, since sip4 is not available for the
    latter.
- Make doc package noarch.
- Have python310-plplot-pyqt5 obsolete plplot-python3-qt5.
- Have python311-plplot explicitly obsolete python3-plplot to
  avoid file conflicts during upgrades.
- Let python310-plplot = %%{version}-%%{release} conflict with
  python3-plplot < %%{version}-%%{release}.
* Wed May  3 2023 Atri Bhattacharya <badshah400@gmail.com>
- Disable octave also for TW (openSUSE >= 1550) since plplot does
  not support octave >= 8.0.
* Sat Feb 26 2022 Max Lin <mlin@suse.com>
- BuildRequires python3-sip4 for Leap 15.4
* Sun Jan 30 2022 Atri Bhattacharya <badshah400@gmail.com>
- Enforce CMAKE_INSTALL_LIBDIR=%%{_libdir} to ensure pkgconfig
  file substitutions for libdir are correct; this became an issue
  after we switched to using the cmake macro for configuring
  (boo#1195074).
* Tue Jul  6 2021 Steve Kowalik <steven.kowalik@suse.com>
- Change shebangs for Python examples to be Python 3.
- Add patch support-python3-pythondemos.patch so pythondemos.py will
  run under Python 3.
* Fri Jul  2 2021 Atri Bhattacharya <badshah400@gmail.com>
- Enable building octave bindings for openSUSE >= 1550 (TW) where
  swig has been patched to support octave 6+.
* Tue Jun  8 2021 Atri Bhattacharya <badshah400@gmail.com>
- Enforce std=c++14 to avoid build failures with GCC 11 that
  defaults to c++17.
* Sun Apr  4 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Reenable qhull support, link against reentrant libqhull_r:
  0001-Use-reentrant-libqhull_r-instead-of-deprecated-libqh.patch
- Some minor specfile cleanups
* Sat Feb 13 2021 Atri Bhattacharya <badshah400@gmail.com>
- Add plplot-drop-FindLua-cmake-module.patch to drop in-house
  FindLua.cmake module, which is severely dated, to use cmake's
  own module and fix building for lua >= 5.4; patch taken from
  upstream.
* Sat Jan  9 2021 Atri Bhattacharya <badshah400@gmail.com>
- Disable octave bindings until compilation against octave 6 is
  fixed (fix should happen mostly in swig, see gh#swig/swig#1893).
* Tue Dec 22 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Fix dependency of -devel package when built without qhull
  support: libcsironn0 does not exist in this case.
* Sat Nov 28 2020 Atri Bhattacharya <badshah400@gmail.com>
- Disable csironn library since it does not build against recent
  qhull (libqhull_r).
- Disable ada bindings: does not build with fPIC.
- BuildRequires: python3-sip4-devel for openSUSE >= 1550 to enable
  pyqt5 bindings.
- Pass `-DCMAKE_SKIP_RPATH:BOOL=OFF
  - DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON` to cmake to fix build issues
  caused by Leap 15.2's incorrect cmake macros (doesn't hurt for
  other distros anyway).
* Tue Jul 21 2020 Atri Bhattacharya <badshah400@gmail.com>
- Disable octave bindings for openSUSE < 1550 where they fail to
  build.
* Mon Jul 20 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints for PowerPC avoid "no space left on device" build error
* Tue Jul 14 2020 Atri Bhattacharya <badshah400@gmail.com>
- Add plplot-include-QPainterPath.patch: Include QPainterPath
  header when building Qt modules, needed for Qt >= 5.15.0; patch
  from upstream.
- Re-enable octave bindings (issue with swig and octave seems to
  be fixed now).
- Reorganise the distribution of cmake files so that each cmake
  file belongs in the right package.
* Mon Feb 24 2020 Atri Bhattacharya <badshah400@gmail.com>
- Re-enable csironn bindings for openSUSE >= 1550 as they build
  again (due to fixes to qhull package).
* Mon Feb 24 2020 olaf@aepfle.de
- add conditional for OCaml bindings, they depend on camlidl
- actually fix the OCaml bindings with plplot-ocaml.patch
- use autosetup, build verbose
* Tue Feb  4 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Do not require libcsironn0 from the -devel package on
  suse_version>=1550, where this is no longer built.
* Fri Dec 13 2019 Atri Bhattacharya <badshah400@gmail.com>
- plplotqt-devel no longer Requires libqt4-devel, instead the
  appropriate Qt5 headers.
* Thu Dec 12 2019 Atri Bhattacharya <badshah400@gmail.com>
- Disable libcsironn on openSUSE >= 1550 to prevent build
  failures.
- Fix shapelib dependency: BuildRequires: pkgconfig(shapelib)
  instead of BuildRequires: shapelib; install additional shapelib
  files as part of plplot-common.
* Thu Sep 26 2019 olaf@aepfle.de
- Add ExclusiveArch, based on build_ada in gcc.spec
* Wed Jun  5 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 5.15.0
  * Bug fixes
  * Update PLplot to be consistent with modern free software
  * Rewrite the configuration of the INSTALL_RPATH target
    property
  * Rewrite the rpath configuration of traditionally built
    examples
  * Factor the PLplot export files
  * Introduce symbolic constants in our color-map routines
  * New implementation of the range checks for the validity of
    cmap0 and cmap1 user input
  * New implementation of the -bg command-line option
  * Implement ctest for the build system of the installed
    examples
* Thu Apr  4 2019 Atri Bhattacharya <badshah400@gmail.com>
- Disable octave bindings until compilation against octave 5.1.x
  is supported.
* Fri Jan 25 2019 badshah400@gmail.com
- Update to version 5.14.0:
  * Update control of Python version
  * Rewrite the build-system logic for determining PYQT_SIP_DIR
    and PYQT_SIP_FLAGS
  * Implement plStatic2dGrid
  * Difference report default device changed from psc to svg
  * Resolve the remaining difference report issues
  * Improve command-line parsing
  * Cleanup of plmap
  * wxwidgets development status
  * First step toward using best CMake-3 practices for our build
    system
  * Update PLplot to be consistent with modern free software
  * Rewrite documentation of PLplot testing
  * Configure the ps and psttf device drivers just like all other
    device drivers
  * Bug fixes
- Drop plplot-fix-pkgconfig-checks.patch: upstreamed.
- Update shlib package names in keeping with upstream so versions.
- Enable octave bindings: compilation against 4.4.x has been fixed
  upstream.
* Fri Nov 30 2018 badshah400@gmail.com
- Add plplot-fix-pkgconfig-checks.patch: Fix pkg-config based
  checks for installed dependencies; patch taken from upstream
  git.
* Tue Jul 31 2018 badshah400@gmail.com
- Re-enable libcsirocsa and libscironn for i586: these are now
  building (go figure!)
* Tue Jun  5 2018 badshah400@gmail.com
- Disable octave bindings until compilation against octave 4.4 is
  sorted out; remove conditionals for setting octave_enabled as
  plplot is unresolvable against openSUSE < 1320 anyway.
* Tue May  8 2018 badshah400@gmail.com
- plplot-devel should not depend on shared libs which are not
  built: %%{csirocsa_shlib} and %%{csironn_shlib} on certain archs.
* Mon May  7 2018 guillaume.gardet@opensuse.org
- Handle aarch64, ppc64 and ppc64le, not only x86_64 for libs
* Thu Apr 26 2018 badshah400@gmail.com
- Fix building for i586 by packaging x86_64-only libraries only
  for the latter arch.
* Fri Feb 16 2018 badshah400@gmail.com
- Remove python3-base from Requires for %%{name}-tcltk; it is
  unneeded in light of python(abi) getting pulled in
  automatically.
* Mon Feb 12 2018 badshah400@gmail.com
- Replace even more python2 Requires with python3 ones; this
  finally fixes build failures on openSUSE:Leap:15.0.
* Mon Feb 12 2018 badshah400@gmail.com
- Swap leftover python2 Requires for explicitly python3 ones,
  rename python package to python3-plplot.
* Fri Dec  1 2017 badshah400@gmail.com
- Switch to using explicit python3 BuildRequires (plplot is
  "unresolvable" for openSUSE <= 1320 anyway); adapt file lists
  accordingly.
- Drop conditionals referring to old openSUSE versions <= 1320.
* Fri Dec  1 2017 dimstar@opensuse.org
- Drop legacy dependencies: pkgconfig(gnome-python-2.0) and
  pkgconfig(pygtk-2.0) are not in use.
* Wed Nov 29 2017 badshah400@gmail.com
- Fix License tag in specfile for plplot-octave subpackage: While
  everything else is licensed as LGPL-2.1+, the Octave bindings
  are licensed as GPL-2.0+.
* Sat Nov 11 2017 badshah400@gmail.com
- Drop BuildRequires on libgnomui and libgnomeprintui, as they are
  not really required any more (boo#1067727).
- Change hashbangs for python based examples so that they refer
  directly to the python binary instead of doing so via env.
* Wed Oct  4 2017 fstrba@suse.com
- Remove the stale gcc-java dependency, since gcc-java is bound to
  go soon and it is really not needed for building here
* Sat Aug 26 2017 badshah400@gmail.com
- Update to version 5.13.0:
  * Bug fixes.
  * The Python binding and examples now work for both Python 2 and
    3.
  * Change the Fortran naming convention.
  * Fix many "space in prefix" issues.
  * Complete rewrite of IPC between -dev wxwidgets and wxPLViewer.
  * Implement a new Windows GDI (wingdi) device driver.
  * Implement new Python extension module to support pytkdemo.
  * Fix OCaml inconsistencies for example 8.
  * Improve the implementation of the OCaml binding.
- Add shapelib BuildRequires for added features.
- Rename fortran shared lib and devel package in keeping with
  corresponding shared object naming changes.
- Use ctest for the check section. This allows the disabling of
  tests that either fail because of issues with the test codes
  themselves (octave), or because of lack of a full Xserver (Qt
  tests).
* Fri Jun 16 2017 alarrosa@suse.com
- Add LDFLAGS=-fPIC to fix the ada compiler test to link successfully
  and enable the generation of ada bindings in Factory.
* Sat Feb 11 2017 jengelh@inai.de
- Remove Requires(post) since there is not even a %%post section.
- Trim descriptions for size, fix wrong summaries.
* Tue Feb  7 2017 badshah400@gmail.com
- Switch to building with Qt5 instead of Qt4.
- Add BuildRequires on qhull, this generates a new shared lib
  now packaged as %%{csironn_shlib}.
- Drop unused cmake variables.
- Rename devel pkgs to follow their corresponding shared library
  nomenclature.
- Split out wxPLViewer into its own subpackage, which is now
  called %%{name}-wxwidgets (the shared lib which was using this
  name previously has been renamed in keeping with shlib policy).
- Drop %%{name}-rpmlintrc file, as it is no longer needed.
- Since version 5.12.0 plplot's fortran bindings depend on
  gcc-fortran >= 6.0.
* Mon Jan 30 2017 badshah400@gmail.com
- Update to version 5.12.0:
  * Bug fixes.
  * Rewrite the CMake Ada language support.
  * Rewrite the Fortran binding.
  * Supply old Fortran binding and examples option.
  * Backwards incompatibilities introduced by the new Fortran
    binding.
  * Examples reworked for the -DPL_DOUBLE=OFF case.
  * Changes to our Ada bindings and examples.
  * Changes to our tclmatrix library.
  * Backwards-incompatible changes to our Tcl/Tk bindings and
    examples.
  * Substantial rewrite of the DocBook documentation.
  * Default page size consistency.
  * Updated D language support.
  * Modernized build-system support for Qt4 and Qt5.
  * Implemented support for pyqt5.
  * Addressed -DPL_DOUBLE=OFF issues.
  * Replaced "Lena" with "Chloe".
  * Removed trailing blanks on most text files in our source tree.
  * Make our wxwidgets find module consistent with the official
    version for CMake-3.7.1.
  * Introduction of two new generic pointer types to help protect
    against a planned future C API breakage.
  * Introduction of additional self-describing names for the types
    of arguments used in our C API.
  * Implement submission of dashboards to the <my.cdash.org> cdash
    server.
  * Substantial update and rename of the Python examples.
  * Linux efficiency improvements for the wxwidgets device driver.
- Drop plplot-cmake36-pkg_check_pkgconfig_macro.patch: upstreamed.
- Rebase plplot-5.9.9-ada-pic.patch for updated version.
- Fix timestamp on previous changelog entry.
- Back to installing plplot.pc by default instead of plplot-c.pc.
- Rename plplot-fortran to libplplotf95-%%{sover} as it now
  contains a single shared lib.
- Apply shared library packaging guidelines wherever appropriate;
  remove corresponding %%{name}-rpmlintrc snippet. Shared lib
  naming not applied to %%{name}-tcltk-libs as all the SO in this
  package are always required together and have their SO numbers
  bumped in lock-step with each other.
- Rename %%{name}-tcltk to %%{name}-tcltk-libs.
- Except for the most basic drivers, package individual drivers in
  their own subpackages. Users need to individually install
  drivers they need, only mem and null drivers will be installed
  by default [with any of the devel pkgs, for example].
- Split out a %%{name}-common package with the most basic drivers
  and common example files included; require it from all driver
  subpackage, and -devel packages.
* Sat Dec 31 2016 bwiedemann@suse.com
- build-fix: kill our Xvfb after use
* Fri Dec  9 2016 badshah400@gmail.com
- plplot.pc installs as plplot-c.pc with cmake >= 3.7.1 (now in
  openSUSE:Factory). Manually install a symlink plplot.pc to
  plplot-c.pc for consistency.
* Tue Oct 18 2016 badshah400@gmail.com
- Temporarily disable octave bindings as a workaround to build
  failures caused by octave's upgrade to version 4.2.0 in Factory.
* Sun Aug 14 2016 badshah400@gmail.com
- Enable tk bindings for all openSUSE versions; problem with
  Xvfb segfaulting that prevent building tk bindings for Leap:42.2
  and > 13.2 are worked around by passing the -noreset option to
  Xvfb (see boo#992429).
* Mon Aug  8 2016 badshah400@gmail.com
- Define macro "octave_enabled" to consistently check when
  octave bindings are disabled (only for openSUSE:Leap:42.1).
- Disable tk bindings also for openSUSE:Leap:42.2 -- it does not
  build because of Xvfb crash (boo#992429).
* Sat Aug  6 2016 badshah400@gmail.com
- Enable octave bindings for openSUSE >= 13.2; builds just fine
  now.
* Sat Aug  6 2016 badshah400@gmail.com
- Add plplot-cmake36-pkg_check_pkgconfig_macro.patch to fix
  plplot's defined pkg_check_pkgconfig macro to work with
  cmake >= 3.6; patch sent upstream.
* Tue Apr 12 2016 normand@linux.vnet.ibm.com
- disable Tk bindings in Factory need more change in spec
  to avoid ppc64 build error.
* Wed Mar 30 2016 badshah400@gmail.com
- Disable octave bindings for openSUSE > 13.2 temporarily until
  related build failures are sorted out.
- Tk in Factory is not compatible with plplot apparently, turn
  off tk bindings until fix found.
- Bump required cmake version to 3.0.2, has been required since
  v5.11.1.
- Some rpmlint warning cleanups from using macros in comments.
* Wed Nov 25 2015 p.drouand@gmail.com
- Remove pkgconfig(libagg) requirement; the package doesn't build
  against it anyway
* Tue Aug 18 2015 badshah400@gmail.com
- Disable octave bindings for openSUSE:42 as it doesn't have
  a recent enough swig (>= 3.0) to support this.
* Thu Aug 13 2015 badshah400@gmail.com
- Update to version 5.11.1:
  + Bug fixes.
  + Improve traditional build linking for nondynamic device
    drivers case.
  + Comply with a NEW value for the CMake CMP0022, CMP0023 and
    CMP0026 policies.
  + Plot labels as date / time are now available for 3D plots.
  + Comprehensive testing script improvements.
  + Build system and file cleanup concerning retired devices.
  + Many improvements and bug fixes for the new wxwidgets device.
  + Substantially improved results for comprehensive testing of
    PLplot on the Cygwin platform.
  + Initial success of comprehensive testing of PLplot on the
    MSYS2 platform.
- Drop plplot-swig-3.0.6.patch: incorporated upstream (use
  - DTRY_OCTAVE4=ON option to build against octave 4.0 if
  available).
- Disable plmeta driver: fails to build.
- Disable building tests: we can't seem to get make check
  working anyway.
* Sun Jul 26 2015 badshah400@gmail.com
- Add plplot-swig-3.0.6.patch to fix builds against swig 3.0.6;
  patch taken from Fedora and accepted upstream.
- Enable octave bindings back, patch against swig to fix its
  octave4 bindings has already entered develprojects and Factory.
- Define %%{lua_version} to be 5.3 for openSUSE > 13.2 (Factory
  has lua 5.3.x now).
- Drop conditionals for EOL openSUSE versions.
* Tue Jun  9 2015 badshah400@gmail.com
- Disable octave bindings for now, since build fails with
  octave >= 4.0 (now in science and TW).
* Mon Apr 13 2015 badshah400@gmail.com
- Update to version 5.11.0:
  + Long list of changes, incl. backward incompatible changes
    over version 5.10.0; see
    /usr/share/doc/packages/plplot/README.release for a full
    list.
- Adapt file-list to dropping of the 'd' suffix for shared libs.
- Drop 0001-fix_for_cmake_3.1.patch: incorporated upstream.
- Enable plmeta driver, it is now actively maintained by
  upstream again.
- Add new binaries and man files installed by upstream.
* Sun Mar 15 2015 jengelh@inai.de
- Remove redundant ldconfig requires
- Build with wxWidgets 3
* Sat Jan 31 2015 sfalken@opensuse.org
- Added 0001-fix_for_cmake_3.1.patch to fix building on cmake>3.0
  http://sourceforge.net/p/plplot/plplot/ci/772223c638ecf5dc740c9f3dd7a6883c6d2c83d2/
* Tue Sep 23 2014 sfalken@opensuse.org
- Added -fno-strict-aliasing to CFLAGS and CXXFLAGS to clear warning:
  [  138s] I: Program is likely to break with new gcc. Try -fno-strict-aliasing.
  [  138s] W: plplot strict-aliasing-punning /home/abuild/rpmbuild/BUILD/plplot-5.10.0/builddir/bindings/java/plplotjavacJAVA_wrap.c:2441, 2454, 2467, 2480, 2493, 2506, 2519, 2532, 2545, 2558, 2571, 2597, 2610, 2623, 2636, 2649, 2662, 2675, 2688, 2701, 2714, 2727, 2740, 2753, 2767, 2777, 10385
* Mon Jul 21 2014 badshah400@gmail.com
- Re-enable the tcl-tk bindings for factory as the problem seems
  to have fixed itself (likely due to tk update).
* Sun Jun 29 2014 badshah400@gmail.com
- Disable tcl-tk bindings for factory until we manage to fix what
  is going wrong.
* Thu Feb 13 2014 badshah400@gmail.com
- Update to version 5.10.0:
  + Update the parts of the build system that find Tcl-related
    software
  + Update api.xml to be consistent with our public API defined by
    plplot.h
- Packaging changes:
  + Drop plplot-avoid-config_h-nameclash.patch: incorporated
    upstream
  + Add BuildRequires: xorg-x11-server as %%configure requires
    x-server to find and enable the tk bindings now
  + Implement a %%check section to carry out build testing, but
    disable actual testing until octave tests are fixed
  + Also package the FAQ file as %%doc.
* Thu Jan 30 2014 badshah400@gmail.com
- Enable octave bindings (requires patched swig version from
  devel:tools:building)
- Add patch plplot-avoid-config_h-nameclash.patch to fix build
  errors when octave bindings are enabled for openSUSE > 13.1;
  patch taken from upstream svn.
* Thu Jan  2 2014 badshah400@gmail.com
-  Turn off octave bindings until bugs with octave >= 3.8.0 are
  fixed upstream.
* Mon Dec 23 2013 badshah400@gmail.com
- Update to version 5.9.11:
  + Change CMake variable NUMERIC_INCLUDE_PATH to
    NUMPY_INCLUDE_PATH
  - Overhaul of the build system and bindings for Tcl and friends
  - Substantial overhaul of the build system for the Qt components
- Packaging changes:
  - Drop patches:
  - plplot-lua-5_2.patch: incorporated upstream
  - plplot-tcl-import-usage.patch: incorporated upstream
  - A shared library file was added to the tcltk bindings, also
    package this appropriately (and its related devel files)
  - BuildRequires: pkgconfig(lasi) for openSUSE 13.1 and above,
    so that psttf driver can be built as well
  - The driver pstex is disabled as recommended by upstream
  - Remove conditionals solely necessitated by EOL versions of
    openSUSE.
* Wed Oct  2 2013 badshah400@gmail.com
- Update to version 5.9.10:
  + The format for map data used by plmap has changed
  + Python support for Numeric has been dropped
  + Backwards-incompatible API change to non-integer line widths
  + Improvements to the build system for the Cygwin case
  + The plcolorbar API has been finalized
  + Documentation of the new legend and color bar capabilities of
    PLplot
  + The D bindings and examples have been converted from the
    old version of D (D1) to the new version of D (D2)
  + The DocBook documentation for PLplot is now generated using
    modern XML/XSL backend tools for DocBook
  + Implement experimental build_projects sub-project
  + Implement extremely simple "00" example
  + Convert to using the Allura form of SourceForge software
  + Use NON_TRANSITIVE linking by default for the shared libraries
    case for all non-windows systems
  + Update f95 examples to take larger advantage of Fortran 95
    capabilities
  + Substantial additions to the doxygen documentation
- Packaging changes:
  + Turn ada bindings back on
  + Remove restriction on lua version used, since package now
    builds with lua version >= 5.2 as well
  + Turn off f77 bindings, as recommended by upstream
  + Drop patches that have been incorporated upstream:
  - plplot-multiarch.patch
  - plplot-gcc-ada46-libs.patch
  - plplot-strncat.patch
- Add plplot-lua-5_2.patch to replace usage of log10, deprecated
  in lua 5.2, in favour of log(,10) in some lua based examples.
* Tue Aug 20 2013 badshah400@gmail.com
- Pass "-DUSE_INTERP_RESULT" to CFLAGS for openSUSE >= 13.1 to fix
  build failures from usage of interp->result which is deprecated
  in Tcl 8.6
- In addition, use plplot-tcl-import-usage.patch to fix type
  inconsistency in Tcl_Import (for >= 13.1 only); re-enable
  building of tck/tk bindings for openSUSE 13.1.
* Tue Aug 20 2013 badshah400@gmail.com
- Disable tck/tk bindings completely for Factory to workaround
  build failures from usage of interp->result which is deprecated
  in Tcl 8.6.
* Sat Dec  8 2012 badshah400@gmail.com
- Disable ada bindings for Factory as they cause build errors.
* Mon Sep 17 2012 idonmez@suse.com
- Add plplot-5.9.9-ada-pic.patch to compile Ada code with -fPIC
* Tue May 29 2012 badshah400@gmail.com
- Enable octave bindings also for openSUSE 12.1; building octave
  bindings fail on openSUSE < 12.1 and have been turned off.
* Mon May 14 2012 badshah400@gmail.com
- Enable octave bindings for openSUSE > 12.1 since octave is now
  in factory. The octave bindings are packaged in a separate
  package called plplot-octave.
* Sun Apr 22 2012 dimstar@opensuse.org
- Extend plplot-gcc-ada46-libs.patch to include gnat-4.7 in plus.
* Sat Apr  7 2012 badshah400@gmail.com
- Update lapack buildrequires in keeping with lapack package
  naming changes in devel project; enables building on openSUSE
  12.1 and 11.4 again.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sun Feb 12 2012 badshah400@gmail.com
- Enable lua bindings for factory again, using BuildRequires:
  pkgconfig(lua) < 5.2.
* Thu Feb  9 2012 badshah400@gmail.com
- Disable lua bindings for factory, since build fails with
  lua > 5.1
* Sun Nov 20 2011 werner.ho@gmx.de
- dropped the qhull requirement from the spec-file
  I've not seen any need of it in the INSTALL/README files
* Tue Oct 18 2011 badshah400@gmail.com
- Update to version 5.9.9
  + Minor bug fixes for Windows platform
* Mon Oct  3 2011 dimstar@opensuse.org
- Fix typo in Patch tagline.
* Mon Aug  8 2011 badshah400@gmail.com
- Enable ada bindings
- Added plplot-gcc-ada46-libs.patch to enable compilation with
  gcc-ada = 4.6
* Mon Aug  1 2011 badshah400@gmail.com
- Update to version 5.9.8 (too many changes, see README.release
  file for changes)
* Sat Jul 16 2011 badshah400@gmail.com
- Configure spec file to allow outputs in jpeg, gif formats
* Sun May 29 2011 badshah400@gmail.com
- Added gcc-c++ dependency for plplot-devel
- Cleanup spec file and correct build dependencies to resolve
  build issues with openSUSE 11.3
* Sat May 28 2011 badshah400@gmail.com
- Rename (sub)packages and cleanup spec file
- Add rpmlintrc file to avoid false-positives
* Tue May 10 2011 badshah400@gmail.com
- Remove misbehaving cmake based examples altogether
* Mon May  9 2011 badshah400@gmail.com
- Initial package (version 5.9.7)
